@@ -6,7 +6,7 @@ use Hashids::Util ':all';
 use Moo;
 use namespace::clean;
 
-our $VERSION = "1.001001";
+our $VERSION = "1.001010";
 
 has salt => ( is => 'ro', default => '' );
 
@@ -101,7 +101,6 @@ sub encode_hex {
     my @num;
     push @num, '1' . substr $str, 0, 11, '' while $str;
 
-    # no warnings 'portable';
     @num = map { bignum(0)->from_hex($_) } @num;
 
     $self->encode(@num);
@@ -112,8 +111,7 @@ sub decode_hex {
 
     my @res = $self->decode($hash);
 
-    # as_hex includes the leading 0x, so we use three instead of 1
-    @res ? join '' => map { substr( bignum($_)->as_hex, 3 ) } @res : '';
+    @res ? join '' => map { substr( bignum($_)->to_hex, 1 ) } @res : '';
 }
 
 sub encrypt {
@@ -245,7 +243,7 @@ Hashids - generate short hashes from numbers
     my $number = $hashids->decode('YDx');      # 123
 
     # or a list
-    $hash = $hashids->encode(1, 2, 3);         # 'eGtrS8'
+    $hash = $hashids->encode(1, 2, 3);         # 'laHquq'
     my @numbers = $hashids->decode('laHquq');  # (1, 2, 3)
 
     # also get results in an arrayref
